<?php
/**
 * Hedwix Outreach functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Hedwix_Outreach
 */

if ( ! function_exists( 'hedwix_outreach_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function hedwix_outreach_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Hedwix Outreach, use a find and replace
		 * to change 'hedwix-outreach' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'hedwix-outreach', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
    add_theme_support( 'title-tag' );
    
    /*
		 * Enable support for custom logo.
		 */
		add_theme_support( 'custom-logo' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
    add_theme_support( 'post-thumbnails' );
    add_image_size( 'hedwix-outreach-featured-banner', 1400, 320, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'hedwix-outreach' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'hedwix_outreach_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

    // Enable support for footer widgets.
    add_theme_support( 'footer-widgets', 4 );

    require_once get_template_directory(). '/inc/footer-widget-area.php';

    global $hedwix_outreach_default_options;
    $hedwix_outreach_default_options = hedwix_outreach_get_default_theme_options();
	}
endif;
add_action( 'after_setup_theme', 'hedwix_outreach_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function hedwix_outreach_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'hedwix_outreach_content_width', 640 );
}
add_action( 'after_setup_theme', 'hedwix_outreach_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function hedwix_outreach_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'hedwix-outreach' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'hedwix-outreach' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'hedwix_outreach_widgets_init' );


/**
 * Register custom fonts.
 */
function hedwix_outreach_fonts_url() {
	$fonts_url = '';
	/**
	 * Translators: If there are characters in your language that are not
	 * supported by Open Sans and Lato, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$open_sans = _x( 'on', 'Open Sans font: on or off', 'hedwix-outreach' );
	$lato = _x( 'on', 'Lato font: on or off', 'hedwix-outreach' );
	$font_families = array();
	if ( 'off' !== $open_sans ) {
		$font_families[] = 'Open Sans:400,700';
	}
	if ( 'off' !== $lato ) {
		$font_families[] = 'Lato:300,400,700';
	}
	if ( in_array( 'on', array($open_sans, $lato) ) ) {
		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}
	return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function hedwix_outreach_scripts() {

  $min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

  $fonts_url = hedwix_outreach_fonts_url();
	if ( ! empty( $fonts_url ) ) {
		wp_enqueue_style( 'hedwix-outreach-google-fonts', $fonts_url, array(), null );
  }
  
  wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/assets/css/font-awesome' . $min . '.css', '', '2.2.1' );

  wp_enqueue_style( 'slick-theme', get_template_directory_uri() .'/assets/css/slick-theme' . $min . '.css', '', '2.2.1' );

	wp_enqueue_style( 'slick', get_template_directory_uri() .'/assets/css/slick' . $min . '.css', '', '2.2.1' );

	wp_enqueue_style( 'hedwix-outreach-style', get_stylesheet_uri(), array(), '1.0' );
  
  wp_enqueue_script( 'jquery-slick', get_template_directory_uri() . '/assets/js/slick' . $min . '.js', array( 'jquery' ), '2.2.1', true );

	wp_enqueue_script( 'matchHeight', get_template_directory_uri() . '/assets/js/jquery.matchHeight' . $min . '.js', array( 'jquery' ), '0.7.2', true );

	wp_enqueue_script( 'hedwix-outreach-custom', get_template_directory_uri() . '/assets/js/custom' . $min . '.js', array( 'jquery' ), '1.2.0', true );

	wp_enqueue_script( 'hedwix-outreach-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix' . $min . '.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'hedwix_outreach_scripts' );


/**
 * Include default theme options.
 */
require_once get_template_directory() . '/inc/customizer/default.php';

/**
 * Load Layout Option.
 */
require_once get_template_directory() . '/inc/layout-option.php';

/**
 * Load theme core functions.
 */
require_once get_template_directory() . '/inc/core.php';

/**
 * Load hooks.
 */
require_once get_template_directory() . '/inc/functions/structure.php';
require_once get_template_directory() . '/inc/functions/basic.php';
require_once get_template_directory() . '/inc/functions/custom.php';

/**
 * Custom template tags for this theme.
 */
require_once get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require_once get_template_directory() . '/inc/customizer.php';

/**
 * Load TGM pluin activation file.
 */
require_once get_template_directory() . '/plugins/class-tgm-plugin-activation.php';

/**
 * Load Site Origin Bundle Hooks.
 */
require_once get_template_directory() . '/inc/functions/so-widgets.php';

/**
 * Load Theme SO Widgets.
 */
if ( class_exists( 'SiteOrigin_Widget' ) ) {

	// Theme widgets.
	$theme_widgets = array(
        'featured-slider',
		'latest-news',
        'address',
        'cta',
        'team',
	);

	$template_dir = get_template_directory();

	foreach ( $theme_widgets as $widget ) {

		require_once $template_dir . '/inc/so-widgets/' . $widget . '/' . $widget . '.php';

	}
}
function hedwix_outreach_add_menu_parent_class( $items ) {
    $parents = array();

    foreach ( $items as $item ) {
        //Check if the item is a parent item
        if ( $item->menu_item_parent && $item->menu_item_parent > 0 ) {
          $parents[] = $item->menu_item_parent;
        }
    }

    foreach ( $items as $item ) {
        if ( in_array( $item->ID, $parents ) ) {
          //Add "dropdown" class to parents
          $item->classes[] = 'dropdown';
        }
    }

    return $items;
}

/**
 * Excerpt.
 */

if ( ! function_exists( 'hedwix_outreach_excerpt_length' ) ) :
	/**
	 * excerpt length.
	 *
	 * @param int $length in words.
	 *
	 */
	function hedwix_outreach_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}

		$length = hedwix_outreach_get_option( 'excerpt_length' );
		$length = ! empty( $length ) ? $length : '25';
		return esc_html( $length );
	}
endif;
add_filter( 'excerpt_length', 'hedwix_outreach_excerpt_length', 999 );

if( ! function_exists( 'hedwix_outreach_excerpt_more' ) ) :
	/**
	 * @param string $more.
	 *
	 * Return string 
	 */
	function hedwix_outreach_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}
		/* translators: %s: post title */
		$more =	sprintf( __( '<span class="screen-reader-text"> "%s"</span>', 'hedwix-outreach' ), get_the_title( get_the_ID() ) );
		return ' &hellip; ' . $more;
	}
endif;	
add_filter('excerpt_more', 'hedwix_outreach_excerpt_more');


/**
* Get sidebar options.
*/

if ( ! function_exists( 'hedwix_outreach_get_sidebar_options' ) ) :

	function hedwix_outreach_get_sidebar_options() {

		global $wp_registered_sidebars;

		$output = array();

		if ( ! empty( $wp_registered_sidebars ) && is_array( $wp_registered_sidebars ) ) {
			foreach ( $wp_registered_sidebars as $key => $sidebar ) {
				$output[ $key ] = $sidebar['name'];
			}
		}

		return $output;

	}

endif;

if ( ! function_exists( 'hedwix_outreach_get_index_page_id' ) ) :

	/**
	 * Get front index page ID.
	 *
	 * @param string $type Type.
	 * @return int Corresponding Page ID.
	 */
	function hedwix_outreach_get_index_page_id( $type = 'front' ) {

		$page = '';

		switch ( $type ) {
			case 'front':
				$page = get_option( 'page_on_front' );
				break;

			case 'blog':
				$page = get_option( 'page_for_posts' );
				break;

			default:
				break;
		}
		$page = absint( $page );
		return $page;

	}
endif;

if ( ! function_exists( 'hedwix_outreach_content_is_pagebuilder' ) ) :

	/**
	 * SiteOrigin Page Builder Content Check.
	 *
	 * Conditionally check if the current page/post was created with
	 * the SiteOrigin Page Builder editor.
	 *
	 * @return bool True if builder page.
	 */
	function hedwix_outreach_content_is_pagebuilder() {
		global $post;

		// Consider empty content the WP editor.
		if ( empty( $post ) ) {
			return false;
		}

		// Does pagebuilder content exist in custom fields?
		$panels_data = get_post_meta( $post->ID, 'panels_data', true );

		return ( empty( $panels_data ) ) ? false : true;
	}

endif;

if ( ! function_exists( 'hedwix_outreach_the_custom_logo' ) ) :

	/**
	 * Render logo.
	 */
	function hedwix_outreach_the_custom_logo() {

		if ( function_exists( 'the_custom_logo' ) ) {
			the_custom_logo();
		}

	}

endif;

/**
 * Imports a predefined demo.
 * @return [type] [description]
 */
function hedwix_outreach_ocdi_import_files() {
	return array(
		array(
			'import_file_name'           => 'Outreach Basic Demo',
      'import_file_url'            => get_template_directory_uri() . '/assets/demo-content/demo_content.xml',
      'import_preview_image_url'   => get_template_directory_uri() . '/screenshot.png',
    ),
	);
}
add_filter( 'pt-ocdi/import_files', 'hedwix_outreach_ocdi_import_files' );

// Disable the ProteusThemes branding notice after successful demo import
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

/**
 *TGM Plugin activation.
*/

add_action( 'tgmpa_register', 'hedwix_outreach_activate_recommended_plugins' );

/**
 * Register recommended plugins.
 */

function hedwix_outreach_activate_recommended_plugins() {

	$plugins = array(

		array(
			'name'     => __( 'Page Builder by SiteOrigin', 'hedwix-outreach' ),
			'slug'     => 'siteorigin-panels',
			'required' => false,
		),
		array(
			'name'     => __( 'SiteOrigin Widgets Bundle', 'hedwix-outreach' ),
			'slug'     => 'so-widgets-bundle',
			'required' => false,
		),
		array(
			'name'     => __( 'Contact Form 7', 'hedwix-outreach' ),
			'slug'     => 'contact-form-7',
			'required' => false,
		),
		array(
			'name'      => esc_html__( 'One Click Demo Import', 'hedwix-outreach' ),
			'slug'      => 'one-click-demo-import',
			'required'  => false,
		),
	);

	$config = array();

  tgmpa( $plugins, $config );
}
